# AppDT
此工具箱可以帮您快速构建Windows应用程序，也可以快速生成安装包。安装完毕后请在命令行中输入“adt”来运行它
# Pyenvdler
此工具随AppDT第三方库版一起安装，exe安装包版暂不提供
- 使用方法：
- 在需要部署环境的目录下打开命令行，输入“Pyenvdler <需部署环境版本>”命令并执行即可
# 升级日志：
- 1、新增部署嵌入式python环境功能Pyenvdler
